Openstack
=========

This workspace contains the basic tasks for provisioning and teardown of openstack clusters

os-server-new
=============
Provisions two new openstack servers

os-sg-new
=========
Creates a new openstack security group

os-vol-new
==========
Provisions a new openstack volume

os-network
==========
Creates a new openstack network

os-router
=========
Creates a new router on an openstack instances

os-subnet
=========
Creates two new openstack subnets on an existing openstack network
